@@ -3,32 +3,20 @@
 
   This file is part of libkdepim.
 
-  Copyright (C) 2000 Don Sanders <sanders@kde.org>
+  SPDX-FileCopyrightText: 2000 Don Sanders <sanders@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef PIMCOMMON_BROADCASTSTATUS_H
-#define PIMCOMMON_BROADCASTSTATUS_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QObject>
 
 #undef None
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
    Provides a singleton which broadcasts status messages by emitting
    signals. Interested mainwindows can connect to the statusMsg()
@@ -74,4 +62,3 @@ protected:
 };
 }
 
-#endif
