@@ -1,19 +1,19 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SHARESERVICEURLMANAGER_H
-#define SHARESERVICEURLMANAGER_H
+#pragma once
 
-#include <QObject>
 #include "pimcommon_export.h"
+#include <QObject>
 #include <QUrl>
 
 class KActionMenu;
 class QAction;
-namespace PimCommon {
+namespace PimCommon
+{
 class ShareServiceUrlManagerPrivate;
 /**
  * @brief The ShareServiceUrlManager class
@@ -24,17 +24,8 @@ class PIMCOMMON_EXPORT ShareServiceUrlManager : public QObject
     Q_OBJECT
 public:
     explicit ShareServiceUrlManager(QObject *parent = nullptr);
-    ~ShareServiceUrlManager();
-    enum ServiceType {
-        Fbook = 0,
-        Twitter,
-        MailTo,
-        LinkedIn,
-        Evernote,
-        Pocket,
-        LiveJournal,
-        ServiceEndType
-    };
+    ~ShareServiceUrlManager() override;
+    enum ServiceType { Fbook = 0, Twitter, MailTo, LinkedIn, Evernote, Pocket, LiveJournal, ServiceEndType };
 
     Q_REQUIRED_RESULT KActionMenu *menu() const;
 
@@ -53,4 +44,3 @@ private:
 };
 }
 Q_DECLARE_METATYPE(PimCommon::ShareServiceUrlManager::ServiceType)
-#endif // SHARESERVICEURLMANAGER_H
